<!doctype html>
<html lang="en">
<head>
  <meta name="viewport" content="width=device-width, initial-scale=1.0" />

  <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
  <meta http-equiv="Content-Style-Type" content="text/css" />

  <link rel="stylesheet" type="text/css" href="static/bootstrap.min.css" />
  <link rel="stylesheet" type="text/css" href="static/bootstrap-toc.min.css" />
  <link rel="stylesheet" type="text/css" href="static/datatables.min.css" />
  <link rel="stylesheet" type="text/css" href="static/template.css" />

  <meta name="generator" content="pandoc" />

$for(author-meta)$
  <meta name="author" content="$author-meta$" />
$endfor$

$if(date-meta)$
  <meta name="date" content="$date-meta$" />
$endif$

  <title>$if(title-prefix)$$title-prefix$ - $endif$$pagetitle$</title>
$if(pdf)$
  <style type="text/css">
    thead { display: table-header-group; }
    tfoot { display: table-row-group; }
    tr { page-break-inside: avoid; }
  </style>
$endif$
  <style type="text/css">code{white-space: pre;}</style>

$if(quotes)$
  <style type="text/css">q { quotes: "“" "”" "‘" "’"; }</style>
$endif$

$if(highlighting-css)$
  <style type="text/css">
$highlighting-css$
  </style>
$endif$

$for(css)$
  <link rel="stylesheet" href="$css$" $if(html5)$$else$type="text/css" $endif$/>
$endfor$

$if(math)$
  $math$
$endif$

$for(header-includes)$
  $header-includes$
$endfor$
</head>
<body data-spy="scroll" data-target="#toc">
  $if(pdf)$
  $else$
  <div id="loadingMask"><span id="loadingMask-text">LOADING ... </span><div id="loadingMask-spinner"></div></div>
  $endif$
  <div class="container-fluid">
    <div class="row">
      $if(toc)$
      <div class="col-md-2 bg-light">
        <nav id="toc" data-toggle="toc" class="sticky-top d-none d-md-block">

        </nav>
      </div>
      $endif$

      <div role="main" class="col-md-9 ml-sm-auto col-lg-10 px-4">
        <div class="justify-content-between flex-wrap flex-md-nowrap align-items-center pt-3 pb-2 mb-3 border-bottom">
          $for(include-before)$
            $include-before$
          $endfor$
          $body$
          $for(include-after)$
            $include-after$
          $endfor$
        </div>

        <div class="page-footer">
          <div class="text-sm-right font-weight-lighter font-italic py-1">
            $if(pdf)$
            Powered
            $else$
            Best experience with <a target="_blank" href="https://www.google.com/chrome/">Chrome</a>,
            powered
            $endif$
            by <a target="_blank" href="https://github.com/pwwang/PyPPL">PyPPL</a> v$pyppl_version$ with <a target="_blank" href="https://github.com/pwwang/pyppl-report">pyppl-report</a> v$report_version$
          </div>
        </div>

      </div>
    </div>

  </div>
  $if(pdf)$
  $else$
  <script src="static/jquery-3.4.1.min.js"></script>
  <script src="static/popper.min.js"></script>
  <script src="static/bootstrap.min.js"></script>
  <script src="static/bootstrap-toc.min.js"></script>
  <script src="static/datatables.min.js"></script>
  <script src="static/template.js"></script>
  $endif$
</body>
</html>
